summaryrefslogtreecommitdiffstats
path: root/korganizer/koagendaitem.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/koagendaitem.cpp')
-rw-r--r--korganizer/koagendaitem.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/korganizer/koagendaitem.cpp b/korganizer/koagendaitem.cpp
index 124102b00..f11ea8c01 100644
--- a/korganizer/koagendaitem.cpp
+++ b/korganizer/koagendaitem.cpp
@@ -562,7 +562,7 @@ void KOAgendaItem::addAttendee( const TQString &newAttendee )
KPIM::getNameAndMail( newAttendee, name, email );
if ( !( name.isEmpty() && email.isEmpty() ) ) {
mIncidence->addAttendee(new Attendee(name,email));
- KMessageBox::information( this, i18n("Attendee \"%1\" added to the calendar item \"%2\"").tqarg(KPIM::normalizedAddress(name, email, TQString())).tqarg(text()), i18n("Attendee added"), "AttendeeDroppedAdded" );
+ KMessageBox::information( this, i18n("Attendee \"%1\" added to the calendar item \"%2\"").arg(KPIM::normalizedAddress(name, email, TQString())).arg(text()), i18n("Attendee added"), "AttendeeDroppedAdded" );
}
}
@@ -739,14 +739,14 @@ void KOAgendaItem::paintEvent( TQPaintEvent *ev )
TQRect visRect = visibleRect();
// when scrolling horizontally in the side-by-side view, the repainted area is clipped
// to the newly visible area, which is a problem since the content changes when visRect
// changes, so tqrepaint the full item in that case
if ( ev->rect() != visRect && visRect.isValid() && ev->rect().isValid() ) {
- tqrepaint( visRect );
+ repaint( visRect );
return;
}
TQPainter p( this );
- const int ft = 2; // frame thickness for tqlayout, see paintFrame()
+ const int ft = 2; // frame thickness for layout, see paintFrame()
const int margin = 1 + ft; // frame + space between frame and content
// General idea is to always show the icons (even in the all-day events).
@@ -769,7 +769,7 @@ void KOAgendaItem::paintEvent( TQPaintEvent *ev )
if ( static_cast<Todo*>(mIncidence)->isOverdue() )
bgColor = KOPrefs::instance()->todoOverdueColor();
else if ( static_cast<Todo*>(mIncidence)->dtDue().date() ==
- TQDateTime::tqcurrentDateTime().date() )
+ TQDateTime::currentDateTime().date() )
bgColor = KOPrefs::instance()->todoDueTodayColor();
}
@@ -838,8 +838,8 @@ void KOAgendaItem::paintEvent( TQPaintEvent *ev )
if ( !isMultiItem() ) {
shortH = KGlobal::locale()->formatTime(mIncidence->dtStart().time());
if (mIncidence->type() != "Todo")
- longH = i18n("%1 - %2").tqarg(shortH)
- .tqarg(KGlobal::locale()->formatTime(mIncidence->dtEnd().time()));
+ longH = i18n("%1 - %2").arg(shortH)
+ .arg(KGlobal::locale()->formatTime(mIncidence->dtEnd().time()));
else
longH = shortH;
} else if ( !mMultiItemInfo->mFirstMultiItem ) {
@@ -847,7 +847,7 @@ void KOAgendaItem::paintEvent( TQPaintEvent *ev )
longH = shortH;
} else {
shortH = KGlobal::locale()->formatTime(mIncidence->dtEnd().time());
- longH = i18n("- %1").tqarg(shortH);
+ longH = i18n("- %1").arg(shortH);
}
KWordWrap *ww = KWordWrap::formatText( fm,
@@ -937,8 +937,8 @@ void KOAgendaItem::paintEvent( TQPaintEvent *ev )
(mIncidence->dtStart() != mIncidence->dtEnd()) ) { // multi days
shortH = longH =
i18n("%1 - %2")
- .tqarg(KGlobal::locale()->formatDate(mIncidence->dtStart().date()))
- .tqarg(KGlobal::locale()->formatDate(mIncidence->dtEnd().date()));
+ .arg(KGlobal::locale()->formatDate(mIncidence->dtStart().date()))
+ .arg(KGlobal::locale()->formatDate(mIncidence->dtEnd().date()));
// paint headline
p.fillRect( 0, 0, width(), (ft/2) + margin + hlHeight,
@@ -739,14 +739,14 @@ void KOAgendaItem::paintEvent( TQPaintEvent *ev )
// when scrolling horizontally in the side-by-side view, the repainted area is clipped
// to the newly visible area, which is a problem since the content changes when visRect
- // changes, so tqrepaint the full item in that case
+ // changes, so repaint the full item in that case
if ( ev->rect() != visRect && visRect.isValid() && ev->rect().isValid() ) {